Outil d'ajout d'images

Outil d'ajout d'images | Table des matières

L'outil d'ajout d'images ouvre la fenêtre ci-dessous.
Vous entrez tout simplement l'adresse de l'image que vous désirez ajouter et entrez une description facultative. La description sera affichée en texte alternatif sur l'image lorsqu'elle sera publiée.
Description des champs:

Adresse de l'image | Adresse URL de l'image à insérer.
Description de l'image | Description alternative de l'image.
Dimensions | Largeur et Hauteur de l'image en pixel.
Alignement | Alignement de l'image. Très utile pour faire contourner le texte autour des images.
Bordure | Épaisseur en pixel de la bordure.
VSpace | Espacement vertical. Très utile pour faire contourner le texte autour des images.
HSpace | Espacement horizontal. Très utile pour faire contourner le texte autour des images.

Aller à: Table des matières | Haut de page